@@ -1,8 +1,6 @@
-from os.path import basename
-
 import torch
 from commode_utils.callback import PrintEpochResultCallback, ModelCheckpointWithUpload
-from omegaconf import DictConfig
+from omegaconf import DictConfig, OmegaConf
 from pytorch_lightning import seed_everything, Trainer, LightningModule, LightningDataModule
 from pytorch_lightning.callbacks import EarlyStopping, LearningRateMonitor
 from pytorch_lightning.loggers import WandbLogger
@@ -13,9 +11,13 @@ def train(model: LightningModule, data_module: LightningDataModule, config: Dict
     params = config.train
 
     # define logger
-    model_name = model.__class__.__name__
-    dataset_name = basename(config.data_folder)
-    wandb_logger = WandbLogger(project=f"{model_name} -- {dataset_name}", log_model=False, offline=config.log_offline)
+    wandb_logger = WandbLogger(
+        project=config.wandb.project,
+        group=config.wandb.group,
+        log_model=False,
+        offline=config.wandb.offline,
+        config=OmegaConf.to_container(config),
+    )
 
     # define model checkpoint callback
     checkpoint_callback = ModelCheckpointWithUpload(
